@@ -5,9 +5,13 @@ viewer
 View meshes and scenes via pyglet or inline HTML.
 """
 
-
 from .. import exceptions
-from .notebook import in_notebook, scene_to_html, scene_to_notebook
+from .notebook import (
+    in_notebook,
+    scene_to_html,
+    scene_to_mo_notebook,
+    scene_to_notebook,
+)
 
 try:
     # try importing windowed which will fail
@@ -31,10 +35,11 @@ except BaseException as E:
 # explicitly list imports in __all__
 # as otherwise flake8 gets mad
 __all__ = [
-    "SceneWidget",
     "SceneViewer",
-    "render_scene",
+    "SceneWidget",
     "in_notebook",
-    "scene_to_notebook",
+    "render_scene",
     "scene_to_html",
+    "scene_to_mo_notebook",
+    "scene_to_notebook",
 ]
